*Anonymize all datasets

********************************************************************************
*Load hhq data and drop unnecessary variables
********************************************************************************

*Load hhq data
use "${gsdData}/0-RawOutput/hhq.dta", clear

*Drop unnecessary variables
keep state ea parent_key enum_identity
sort state ea parent_key

********************************************************************************
*Set seed
********************************************************************************

*Set seed
set seed 10051990 

********************************************************************************
*Generate random ID for each household
********************************************************************************
*Generate random variable 
gen rand = runiform()
*Generate anonymized HH ID
sort state ea parent_key
by state ea: egen hh_anon = rank(rand)
*Save household anonymization key
save "${gsdData}/0-RawTemp/hh_anonkey.dta", replace

********************************************************************************
*Generate random ID for each EA
********************************************************************************

*Take mean of random variable at the EA level
collapse (mean) rand, by(state ea)
sort state ea
*Generate anonymized EA ID using mean of random variable
by state: egen ea_anon = rank(rand)
replace ea_anon=100+ea_anon
*Save EA anonymization key
save "${gsdData}/0-RawTemp/ea_anonkey.dta", replace

********************************************************************************
*Generate random ID for each enumerator
********************************************************************************

*match with enumerator identities from waves 1 and 2
import excel using "${gsdDataRaw}/General/enum_id_previouswaves.xlsx", first clear
merge 1:m enum_identity using "${gsdData}/0-RawTemp/hh_anonkey.dta", assert(match) nogen 
*Take mean of random variable at enumerator level
collapse (mean) rand enum_m, by(enum_identity)
*remove unknown enumerator names
replace rand=. if !missing(enum_m_old)
replace rand=. if substr(enum_identity,1,7)=="unknown"
sort enum_m_old rand
gen enum_m=enum_m_old
replace enum_m=enum_m[_n-1]+1 if missing(enum_m) 
replace enum_m=. if substr(enum_identity,1,7)=="unknown"
*Generate anonymized enum ID using mean of random variable
rename enum_m enum_anon
drop enum_m_old rand
*match enumerators who were hired in waves 1 and 2 with their ID's
*Save enumerator anonymization key
save "${gsdData}/0-RawTemp/enum_anonkey.dta", replace

********************************************************************************
*Anonymize hhq data
********************************************************************************

*Load hhq data
use "${gsdData}/0-RawTemp/hhq_withweights.dta", clear
*Merge anonymized household IDs
merge 1:1 parent_key using "${gsdData}/0-RawTemp/hh_anonkey.dta", assert(match) keep(match master) keepusing(hh_anon) nogenerate
*Merge anonymized EA IDs
merge m:1 ea using "${gsdData}/0-RawTemp/ea_anonkey.dta", assert(match) keep(match master) keepusing(ea_anon) nogenerate
*Merge anonymized enumerator IDs
merge m:1 enum_identity using "${gsdData}/0-RawTemp/enum_anonkey.dta", assert(match) keep(match master) keepusing(enum_anon) nogenerate
*Drop identifying information
drop ea replace_yn parent_key enum_identity  device* subscribe* hhh_name hh_id hhh_name hhr_id loc* countyborn hhh_migra_from_county
*Rename
rename (ea_anon hh_anon enum_anon) (ea hh enum)
*Sort and reorder
sort state ea hh
order state ea hh
*Save anonymized hhq data
save "${gsdData}/0-RawTemp/hhq_anon.dta", replace

********************************************************************************
*Anonymize hhm data
********************************************************************************

*Load hhm data
use "${gsdData}/0-RawOutput/hhm.dta", clear
sort parent_key member_key
*Merge anonymized household IDs
merge m:1 parent_key using "${gsdData}/0-RawTemp/hh_anonkey.dta", assert(match) keep(match master) keepusing(hh_anon) nogenerate
*Merge state and non-anonymized EAs
merge m:1 parent_key using "${gsdData}/0-RawOutput\hhq.dta" , assert(match) keep(match master) keepusing(state ea) nogenerate
*Merge anonymized EA IDs
merge m:1 ea using "${gsdData}/0-RawTemp/ea_anonkey.dta", assert(match) keep(match master) keepusing(ea_anon) nogenerate
*Drop identifying information
drop ea parent_key name
*Rename and reorder
rename (ea_anon hh_anon) (ea hh)
order state ea hh
sort state ea hh hhmid
*Save anonymized hhm data
save "${gsdData}/0-RawTemp/hhm_anon.dta", replace

********************************************************************************
*Anonymize consumption data
********************************************************************************

foreach sf in food nonfood livestock assets {
	*Load consumption data
	use "${gsdData}/0-RawOutput/`sf'.dta", clear
	if "`sf'"=="food" | "`sf'"=="nonfood" {
		sort parent_key item_category itemid
		}
	else if "`sf'"=="livestock" {
		sort parent_key index
		}
	else if "`sf'"=="assets" {
		sort parent_key index
		}
	*Merge anonymized household IDs
	merge m:1 parent_key using "${gsdData}/0-RawTemp/hh_anonkey.dta", assert(match) keep(match master) keepusing(hh_anon) nogenerate
	*Merge state and non-anonymized EAs
	merge m:1 parent_key using "${gsdData}/0-RawOutput/hhq.dta", assert(match) keep(match master) keepusing(state ea) nogenerate
	*Merge anonymized EA IDs
	merge m:1 ea using "${gsdData}/0-RawTemp/ea_anonkey.dta", assert(match) keep(match master) keepusing(ea_anon) nogenerate
	*Drop identifying information
	drop ea parent_key
	*Rename and reorder
	rename (ea_anon hh_anon) (ea hh)
	order state ea hh
	sort state ea hh
	*Save anonymized consumption data
	save "${gsdData}/0-RawTemp/`sf'_anon.dta", replace
}
