*this do file prepares shareable version of hhq 
* This do file prepares sharable version of hhq input file  
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*Prepare hhq
*bring in nhhm variable from hhm data
use "${gsdData}/0-RawTemp/hhm_anon.dta", clear
collapse nhhm, by (state ea hh)
label var nhhm "Household size"
rename nhhm hhsize
merge 1:1 state ea hh using "${gsdData}/0-RawTemp/hhq_anon.dta", assert(match) keep(match) nogen
rename Urbanicity urban
*Rename variables by adding relevant prefixes
*Shortening one variable name
ren resolving_community_conflict resolve_comm_conflict
*Tag non-sn items
local nonsn "state ea hh stratum enum weight mod_hh hhsize replacement duration month urban start_time end_time today_auto today_manu"
ds `nonsn', not
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1,`space'-1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","_",4)
	*Rename variables their respective item numbers
	rename `var' `sn'_`var'
} 
*Assign appropriate labels to variables 
label var ea "Enumeration Area"
label var hh "Household ID"
label var enum "Enumerator ID"
label var duration "Duration of interview (minutes)"
label var mod_hh "Household module assignment"
*9 interviews with missing month, replace with median
quietly su month, detail
replace month=r(p50) if missing(month)
label var month "Month of Interview"
*Reorder based on alphabetic-numeric order
order *, sequential
order state ea hh stratum urban weight hhsize, first
order month enum duration mod_hh, last
*drop unecessary variables 
drop replacement end_time start_time today_auto today_manu A_2_int_num duration 
*drop variables containing confidential information
drop J_1_contact_phone_yn J_2_contact_phone_share J_3_contact_phone K_10_enum_comments I_93_harm_location_spec
save "${gsdData}/1-CleanInput/hhq.dta", replace

*prepare hhm
use "${gsdData}/0-RawTemp/hhm_anon.dta", clear
*Rename variables by adding relevant prefixes 
label var age "B.2 Household member age"
*Tag non-sn items
local nonsn "state ea hh hhmid"
ds `nonsn', not
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space'-1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","_",4)
	*Rename variables their respective item numbers
	rename `var' `sn'_`var'
} 
*drop unecessary variables
drop Unique_member_key	*dk _*
*order
order *, sequential
order state ea hh hhmid 
order BW*, last
*fix some labels
label var ea "Enumeration Area"
label var hh "Household ID"
label define lishead 0 "No" 1 "Yes", modify
label val B_3_ishead lishead
sort state ea hh
save "${gsdData}/1-CleanInput/hhm.dta", replace
 
*prepare food
*Place median foodprices from wave 1 to later calculate the deflator
import delimited using "${gsdDataRaw}/General/foodprices_medians_W1.csv" , clear
keep if tm=="2015m7"
drop tm 
rename (uprice urban) (ref urb)
gen urban=urb=="Urban"
save "${gsdTemp}/food-prices_W1.dta", replace
*Place median foodprices from wave 1 to later calculate the deflator
import excel using "${gsdDataRaw}/General/food_price_constraints.xlsx" , clear first 
format v* %8.2g
replace v_max=. if v_max<1
save "${gsdTemp}/food_price_constraints.dta", replace
*prepare food data
use "${gsdData}/0-RawTemp/food_anon.dta", clear
format item_category item_name %32.0f
sort state ea hh itemid
*create item recall variable
gen item_recall=7 if !missing(relevanceyn) 
label var item_recall "Recall period, days"
order item_recall, after(itemid)
*drop redundant variables
drop key
*drop constraints because they are not regular, and instead merge a clean file
drop pric_min pric_max 
merge m:1 itemid using "${gsdTemp}/food_price_constraints.dta", nogen assert(match) keepusing(v_min v_max)
order v_min v_max, after(pric_total_sp)
*Tag non-sn items
ds relevanceyn cons_quant cons_unit cons_estkg maj_ownprod purc_quant purc_unit purc_estkg pric_total pric_total_curr pric_total_sp free_yn free_main free_other, 
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space'-1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","_",4)
	*Rename variables their respective item numbers
	rename `var' `sn'_`var'
} 
*format nicely
local numerical_format "E_2_cons_quant E_3_cons_unit c_min_s c_max_s c_min_h c_max_h E_7_cons_estkg cons_conv2kg cons_quant_kg E_9_purc_quant E_10_purc_unit p_min_s p_max_s p_min_h p_max_h E_14_purc_estkg purc_conv2kg purc_quant_kg E_15_pric_total"
format `numerical_format' %9.0g
*Add labels
label var ea "Enumeration Area"
label var hh "Household ID"
save "${gsdData}/1-CleanInput/food.dta" , replace

*prepare nonfood
*prepare nonfood price constraints
import delimited using "${gsdDataRaw}/General/section_f.csv", clear varn(1) 
keep itemid v_min v_max
save "${gsdData}/1-CleanInput/Other/nonfood_constraints.dta", replace
*merge with nonfood constraints
use "${gsdData}/0-RawTemp/nonfood_anon.dta", clear
format item_category itemlabel %32.0f
merge m:1 itemid using "${gsdData}/1-CleanInput/Other/nonfood_constraints.dta", nogen assert(match)
label var v_min "Minimum price constraint"
label var v_max "Maximum price constraint"
sort state ea hh itemid
rename mod_item item_module
order item_module, after(itemid)
order v_min v_max, last
*drop redundant variables
drop key generated_note_* pric_ssp 
*Save variable names and variable labels
ds cons price curr pric_total_sp pric_zero free_yn free_main free_other
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space'-1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","_",4)
	*Rename variables their respective item numbers
	rename `var' `sn'_`var'
} 
*Add labels
label var ea "Enumeration Area"
label var hh "Household ID"
save "${gsdData}/1-CleanInput/nonfood.dta" , replace

*prepare assets
*create median wave 1 depreciation rates
import delimited using "${gsdDataRaw}/General/depreciation_rates_W1.csv" , clear  
save "${gsdData}/1-CleanInput/Other/drate_w1.dta" , replace
*get asset prices from wave1
use "${gsdDataRaw}/General/assets_prices_W1.dta" , clear  
save "${gsdData}/1-CleanInput/Other/assets_prices_w1.dta" , replace
*Load anonymized assets data 
use "${gsdData}/0-RawTemp/assets_anon.dta", clear
sort state ea hh index
*Save variable names and variable labels
label var own_preconflict "H.25 Did the household own any of ${ra_namelp} before the conflict?"
ds state ea hh index max_h, not
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space'-1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","_",4)
	*Rename variables their respective item numbers
	rename `var' `sn'_`var'
} 
*Add labels
label var ea "Enumeration Area"
label var hh "Household ID"
label var index "Asset"
label var max_h "Maximum hard constraint"
order H_8_prnew_curr, before(H_10_prnew_sp)
save "${gsdData}/1-CleanInput/assets.dta" , replace
 
*prepare livestock
*Load anonymized livestock data
use "${gsdData}/0-RawTemp/livestock_anon.dta", clear
sort state ea hh index 
order max_s, before(max_h)
*rename variables
ds state ea hh index max_h max_s, not
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space'-1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","_",4)
	*Rename variables their respective item numbers
	rename `var' `sn'_`var'
} 
*Add labels
label var ea "Enumeration Area"
label var hh "Household ID"
label var index "Livestock"
label var max_h "Maximum hard constraint"
label var max_s "Maximum soft constraint"
save "${gsdData}/1-CleanInput/livestock.dta" , replace

*create file with CPI from Wave1 onwards for constraints and deflator
import excel using "${gsdDataRaw}/General/CPI_Website_July 2017.xlsm", clear first cellrange(B2:DZ26)
drop Coicop WeightCoicop3 WeightCoicop2 WeightCoicop4 Apr2007-Jan2015 Mar2015-Jun2015 Aug2015-Aug2016 May2017-July2017
keep if Itemdescription=="All item index" | Itemdescription=="CPI excluding unprocessed food and petrol" | Itemdescription=="Food and Non-alcholic beverages"
replace Itemdescription="CPI" if Itemdescription=="All item index"
replace Itemdescription="CPI_food" if Itemdescription=="Food and Non-alcholic beverages"
replace Itemdescription="CPI_nonfood" if Itemdescription=="CPI excluding unprocessed food and petrol"
gen n=_n
reshape wide Feb2015-Apr2017, i(n) j(Itemdescription, string)
foreach v of varlist Feb2015CPI_food-Apr2017CPI_nonfood {
	replace `v'=`v'[_n+1] if n==1 
	replace `v'=`v'[_n+2] if n==1 & missing(`v')
}
keep if n==1
reshape long @CPI @CPI_nonfood @CPI_food, i(n) j(m, string)
gen mo=date(m,"MY")
gen month=mofd(mo)
format month %tm
drop m mo n
foreach v of varlist CPI CPI_nonfood CPI_food {
	egen ref_`v'_Feb2015=min(`v')
	gen x`v'=`v' if month==tm(2015m7)
	egen ref_`v'_July2015=max(x`v')
	drop x*
}
save "${gsdData}/1-CleanInput/Other/CPI_NBS.dta", replace

*prepare USD/SSP exchange rate data
import excel using "${gsdDataRaw}/General/HFS-SSD-MPS-Tableau.xlsx", sheet("ERS") clear first
keep if inrange(Date,td(01/1/2012),td(30/04/2017))
drop if Outlier==1
drop Outlier
keep if Type=="Parallel" & Transaction=="Midpoint"
*get national average exchange rate by month
gen month=mofd(Date)
format month %tm
collapse (mean) Value, by(month)
rename Value er
replace er=er/100
label var er "SSP/USD Exchange rate"
save "${gsdTemp}/exchange_rate_usd_month.dta", replace

*prepare other currencies exchange rate data (prepare one monthly dataset over the survey period for consumption data and one yearly dataset for assets)
import delimited using "${gsdDataRaw}/General/rates_data.csv" , clear rowrange(6:292) varn(6)
gen d=date(periodstartdate,"YMD")
format d %td
gen month=mofd(d)
format m %tm
drop d periodstartdate
order month, first
*clean low rates in sdp
replace usdsdp=usdsdp*100 if usdsdp<100
replace usdsdp=usdsdp*10 if usdsdp<200
*merge with ERS data
merge 1:1 month using "${gsdTemp}/exchange_rate_usd_month.dta", nogen assert(match master) 
drop if month>tm(2017m4)
*replace ssp data for pre 2011 years with SDG
replace er=usdsdg if missing(er) 
*replace ssp data with sdd/100 for pre 2007 years
replace er=usdsdd/100 if missing(er)
*rename data
rename er usdssp
save "${gsdData}/1-CleanInput/Other/exchange_rates_month.dta", replace
*create USD exchange rate
gen usdusd=1
ds month, not
foreach v in `r(varlist)' {
	local s = strupper("`v'")
	rename `v' `s'
}
reshape long USD, i(month) j(curr, string)
rename USD conv2usd
drop if missing(conv2usd)
*spread usdssp er to every year
gen x=conv2usd if curr=="SSP"
bys month: egen conv2ssp=max(x)
drop x
sort curr month
save "${gsdData}/1-CleanInput/Other/exchange_rates_month_assets.dta", replace

*create yearly exchange rate data
use "${gsdTemp}/exchange_rates_month.dta", clear
gen year=yofd(dofm(month))
*create USD exchange rate
gen usdusd=1
collapse usd* , by(year)
ds year, not
foreach v in `r(varlist)' {
	local s = strupper("`v'")
	rename `v' `s'
}
reshape long USD, i(year) j(curr, string)
rename USD conv2usd
drop if missing(conv2usd)
*spread usdssp er to every year
gen x=conv2usd if curr=="SSP"
bys year: egen conv2ssp=max(x)
drop x
sort curr year
save "${gsdData}/1-CleanInput/Other/exchange_rates_year.dta", replace

*prepare wave 1 depreciation rates
import delimited using "${gsdDataRaw}/General/depreciation_rates_W1.csv", varn(1) clear
drop if missing(index)
save "${gsdData}/1-CleanInput/Other/drate_w1.dta", replace

*create separate crs and hfs datasets
/*
local data = "hhq assets food nonfood livestock hhm hhm_separated"
local set = "CRS HFS"
foreach s of local set {
	foreach d of local data {
		use "${gsdData}/1-CleanInput/`d'.dta" , clear
		if "`s'"=="CRS" {
			keep if dataset==1 
			save "${gsdData}/1-CleanInput/CRS/`d'.dta" , replace
		}
		else if "`s'"=="HFS" {
			keep if dataset==2
			save "${gsdData}/1-CleanInput/HFS/`d'.dta" , replace
		}		
	}
}
*/
