*This file 
	*	Aggregates non missing values for each household.
	*	Identify duplicate observations.
	*	Clean and consolidate variables	
use "${gsdData}/0-RawTemp/hhq_labelled_corrected.dta", clear

*Dropping unncecessary variables. 
*These variables are system-generated and have missing values for all the 1880 observations in the data. 
foreach var of varlist stop gg_etime generate*  hhm_name_28 hhm_name_29 hhm_name_30 hhh_religion_spec{
	tab `var'
	assert r(N) == 0
	drop `var'
}
*dropping unnecessary variables:
drop audio* treat_training hhsid hhsid_replace

foreach var of varlist hhlid_check ea_barcode_yn ea_barcode_conf {
	tab `var'
	assert `var' == 1 if !missing(`var') 
	drop `var'
}
*Drop wrongly calculated variables:
drop nhhm

*Formatting variables:
*Renaming variables to make consistent with previous waves.
*Convert date variables from string to numeric
local datea today my_date
local dateb submissiondate start_time end_time 
local datea_cmd "date"
local dateb_cmd "clock"
local datea_fmt "MDY"
local dateb_fmt "MDYhms"
foreach list in a b {
	foreach d of local date`list' {
	gen double `d'_n = `date`list'_cmd'(`d', "`date`list'_fmt'")
	drop `d'
	format %td `d'_n
	rename `d'_n `d'
	}
}
*Reformat numeric date variables
format %td `datea'
format %tc `dateb'

*Reformat long numeric variables
format ea %14.0g
format deviceid %17.0g
format subscriberid %17.0g
ren (today my_date) (today_auto today_manu)

*3.1 Format time data
*Calculate interview time and drop any interviews longer than 5 hours long.
gen duration=end_time-start_time
replace duration=round(duration/(60*1000))
label var duration"Interview duration (minutes)"
*flag very long interviews
gen interview_toolong = (duration>300)
*set as missing the suspiciously long interviews and interviews durations that are negative
*replace duration=. if duration>300
*replace duration=. if duration<0
*some dates are too far back, replace with submissiondate
replace today_auto=submissiondate if today_auto<td(01092016)
replace today_manu=submissiondate if today_manu<td(01092016)
*Create month variable:
gen month = mofd(today_auto)
label var month "Month of interview"
format %tm month

*Compute non-missing values for all modules of raw data
*Save data prior to generating non-missing values
save "${gsdTemp}/pregen_nonmissing.dta", replace
*Generate count of non-missing values for each observation (including missing values of string variables) and save non-missing count
egen rownonmiss_hhq = rownonmiss(*), strok
keep rownonmiss_hhq parent_key
save "${gsdData}/0-RawTemp/nonmissing_hhq.dta", replace
*Next generate count of non-missing values across all other sets of raw data
foreach sf in hhm livestock assets food nonfood {
	*Load data
	use "${gsdDataRaw}/`sf'.dta", clear
	*Generate number of non-missing values
	egen rownonmiss_`sf' = rownonmiss(*), strok
	*Collapse to household level
	collapse (sum) rownonmiss_`sf', by(parent_key)
	save "${gsdData}/0-RawTemp/nonmissing_`sf'.dta", replace
}
*Merge non-missing values from all other sets of raw data
use "${gsdTemp}/pregen_nonmissing.dta", clear
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_hhq.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_hhm.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_livestock.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_assets.dta", keep(match master) nogenerate
*Aggregate non-missing values for each household
gen rownonmiss = rownonmiss_hhq + rownonmiss_hhm + rownonmiss_livestock + rownonmiss_assets
*Drop empty rows in hhq data
drop if rownonmiss_hhq == 0


*Cleaning Name Variables - Removing leading and trailing blanks and changing all alphabets to upper case.
foreach var of varlist enum_name enum_identity team_name hhm_name* hhr_name hhh_name* {
	replace `var' = strtrim(`var')
	replace `var' = upper(`var')
}
*Drop intermediary variables used to calculate hhh_name and hhr_name
assert hhh_name == hhh_name0 if hhh_presence > 0 & !missing(hhh_presence)
replace hhh_name = hhh_name0 if hhh_presence == 0 & missing(hhh_name)
assert !missing(hhh_name)
assert hhh_age == hhh_age0 if hhh_presence > 0 & !missing(hhh_presence)
assert hhh_age == hhh_age0 if hhh_presence == 0 & missing(hhh_age1)
drop hhr_id hhh_id0 hhh_name0 hhh_presence hhh_id1 hhh_options hhh_id hhh_age0 hhh_age0_18 hhh_age1 hhh_age1_18
*Investigate range of respondent ages
tab res_age
*Tabulate distribution of respondent ages for respondents who are less than or equal to 18 years of age
tab res_age if res_age <= 18
tabout res_age if res_age <= 18 using "${gsdOutput}/tab_age.txt", cells(freq) format(0c) clab(Freq.) replace
*Look at records with respondents who are less than or equal to 18 years of age
sort res_age
list hhr_name res_age parent_key if res_age <= 18
list hhr_name res_age parent_key if res_age <= 18 & hhr_name != ""
*Set age to missing for respondents who are recorded as 17 years old or younger
replace res_age = . if res_age < 18

*Consolidating variables identifying geolocation
replace loclatitude = loc_endlatitude if missing(loclatitude)
replace loclongitude = loc_endlongitude if missing(loclongitude)
replace localtitude = loc_endaltitude if missing(localtitude)
replace locaccuracy = loc_endaccuracy if missing(locaccuracy)
drop loc_end* loc_check* gps*
*Removing unnecessary enumerator identifying variables
drop qr_id qr_idcheck qr_noid team_id enum_id enum_name team_name enum_check enum_identity
rename enum_clean enum_identity
*Cleaning qr_resp_id
*Cleaning of QR_RESP_ID
gen length = length(qr_resp_id)
*qr_resp_id is a 6 digit barcode given to household repsondents.
*QR Codes were printed differently. Extracting the numeric part of the qr_codes.
gen qr_resp_clean = qr_resp_id if length(qr_resp_id) == 6
replace qr_resp_clean = substr(qr_resp_id,10,6) if length(qr_resp_id) == 15
replace qr_resp_clean = substr(qr_resp_id,11,6) if length(qr_resp_id) == 16
duplicates tag qr_resp_clean if !missing(qr_resp_clean), generate(tag1)
tab tag1, mi
bysort qr_resp_clean: gen nqr = _N
*qr_code 930001 appears 28 times. 
replace qr_resp_clean = "" if qr_resp_clean == "930001"
*Certain qr_codes appear 2 or 3 times.
sort qr_resp_clean today_auto start_time
list qr_resp_clean today_auto start_time if nqr >1
*The interview dates are well separated.
*Dropping all duplicate observations of qr_resp_clean
replace qr_resp_clean = "" if nqr >1
_crcslbl qr_resp_clean qr_resp_id
drop qr_resp_id nqr tag1
ren qr_resp_clean qr_resp_id
*Split and destring various string variables - 
foreach var of varlist hhh_religion move_why_multi move_return_other move_help harm_12m harm_help_spec respondent_q_section {
	*Obtain old label
	local oldlabel : variable label `var'
	*Split string variable
	split `var', parse(" ")
	forvalues i = 1/`r(nvars)' {
		*Destring split string variables
		quietly destring `var'`i', replace
		*Apply old label to split variables
		label var `var'`i' "`oldlabel'"
	}
	*Drop original string variable
	drop `var'
}
label define hhh_religion 1 "Christianity" 2 "Islam" 3 "Traditional African Religion" 4 "Judaism" 5 "Buddhism" 6 "Hinduism" 7 "Agnostic" 8 "Atheism" 9 "Non-believer" 1000 "Other (Specify)" -98 "Don't know" -99 "Refused to respond"
label values hhh_religion* hhh_religion
label define move_why_multi 1 "Belongings stolen" 2 "Absence of authority" 3 "Do not feel safe" 4 "No financial means to return" 5 "House damaged/destroyed" 6 "Work tools stolen" 7 "I want to wait for the political situation to develop/stabilize" 8 "I want to receive humanitarian aid" 9 "I participate in economic activities here" 10 "I don't have income anymore when I return" 11 "I have better access to education here" 12 "I have better access to health here" 1000 "Other (Specify)" -98 "Don't knpw" -99 "Refused to respond"
label values move_why_multi* move_why_multi
forvalues i = 1/5 {
	label values move_return_other`i' move_return
}
label define move_help 0 "None" 1 "Security" 2 "Housing" 3 "Non-food items" 4 "Employment" 5 "Food" 6 "Furniture" 7 "Access to health services" 8 "Phychosocial support" 9 "Training" 10 "Education" 11 "Access to water" 12 "Transport" -98 "Don't know" -99 "Refused to respond"
label values move_help* move_help
label values harm_12m* harm_one
label define harm_help_spec 1 "Medical care" 2 "Psychosocial care/counselling" 3 "Moral support" 4 "Community support" 5 "Counseling from religious/tribal leaders" 6 "Financial support" 7 "Preventive information" 8 "Legal support"
label values harm_help_spec* harm_help_spec
*Identify potential duplicates
*Tag potential duplicate #1: records with identical GPS coordinates
duplicates tag loclatitude loclongitude localtitude if !missing(loclatitude) , generate(tag1)
replace tag1 = 0 if tag1 == .
*Tag potential duplicate #2: records with identical respondent names
duplicates tag hhr_name, generate(tag2)
*Tag potential duplicate #3: records with identical household head names
duplicates tag hhh_name, generate(tag3)
*Generate group indicators within each duplicate type
*Tag groups within duplicate type #1
egen duplicategroup_hhq_1 = group(loclatitude loclongitude localtitude) if tag1 == 1
*Tag groups within duplicate type #2
egen duplicategroup_hhq_2 = group(hhr_name) if tag2 == 1 
*Tag groups within duplicate type #3
egen duplicategroup_hhq_3 = group(hhh_name) if tag3 == 1
*Compute distance between groups within duplicate types #2 and #3
*Compute distance between groups of potential duplicates in categories #2 and #3
do "${gsdDo}/fDistance.do"
foreach num of numlist 2 3 {
	sort duplicategroup_hhq_`num', stable
	bysort duplicategroup_hhq_`num': gen loclatitude_a = loclatitude[_n+1] if duplicategroup_hhq_`num' != .
	bysort duplicategroup_hhq_`num': gen loclongitude_a = loclongitude[_n+1] if duplicategroup_hhq_`num' != .
	quietly fDistance loclatitude loclongitude loclatitude_a loclongitude_a dist_`num' if duplicategroup_hhq_`num' != .
	drop loclatitude_a loclongitude_a
}
*Generate master distance variable for potential duplicates #2 and #3
gen dist = dist_2 if duplicategroup_hhq_2 != .
replace dist = dist_3 if duplicategroup_hhq_3 != .
drop dist_2 dist_3
*Generate a variable identifying how many household member names are exactly repeated across the duplicate observations.
sort duplicategroup_hhq*
gen hhm_n = 0
forvalues i = 1/20 {
	forvalues j = 1/20 {
	replace hhm_n = hhm_n+1 if hhm_name_`i' == hhm_name_`j'[_n+1] & hhm_name_`i'!=""
	}
}
*Manually inspect potential duplicate records
*Manually inspect potential duplicates #1 - There are no duplicates #1
sort tag1 duplicategroup_hhq_1
list hhh_name enum_identity today_auto today_manu start_time end_time if tag1 == 1
*Manually inspect potential duplicates #2
sort duplicategroup_hhq_2 today_auto
list duplicategroup_hhq_2 hhh_name dist hhm_n ea enum_identity today_auto today_manu start_time end_time roster return visit_n success_interview rownonmiss parent_key hh_id if tag2 == 1
*Manual inspection shows that the observations for which duplicategroup_hhq_2 = 1 appears to be duplicate on the basis of geographic location and name of household head.
bysort duplicategroup_hhq_2: egen min = min(rownonmiss) if duplicategroup_hhq_2 == 1 
drop if rownonmiss == min & duplicategroup_hhq_2 == 1
drop min
*Manually inspect potential duplicate #3
sort duplicategroup_hhq_3 today_auto
list duplicategroup_hhq_3 hhr_name dist hhm_n ea enum_identity today_auto today_manu start_time end_time roster hh_id if tag3 == 1
*Manual inspection shows that there are three households with duplicate hhh_name. These households are within the same enumeration area. The age of the household head also matches.
bysort duplicategroup_hhq_3: egen min = min(rownonmiss) if duplicategroup_hhq_3 == 1 |  duplicategroup_hhq_3 == 2 | duplicategroup_hhq_3 == 3
drop if rownonmiss == min & (duplicategroup_hhq_3 == 1 |  duplicategroup_hhq_3 == 2 | duplicategroup_hhq_3 == 3)
drop min
*Further drop unnecessary variables
drop rownonmiss* dist duplicate* set* dur_mod* hhlid_1 hhlid_2* *gg* rep_* roster validnames* modules hhm_all hhm_count hhm_name* hhm_n formdef_version return visit_n
ren s_v state
order ea state loc*, after(submissiondate)
*Fix order
*Tag non-sn items
local nonsn "state ea parent_key enum_identity treat hh_id hhr_name hhh_name res_age res_work res_active sws"
ds `nonsn', not
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space' - 1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","",4)
	*Rename variables their respective item numbers
	rename `var' `sn'`var'
}
*Reorder based on alphabetic-numeric order
order *, sequential
*Tag non-sn items
ds `nonsn', not
*Restore original variable names
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space' - 1)
	*Remove period from item numbers	
	local sn = subinstr(`"`sn'"',".","",4)
	*Create new variable names that do not include the item numbers incorporated earlier
	local newvar = subinstr("`var'","`sn'","",1)
	*Rename variables their earlier variable names
	rename `var' `newvar'
}
*Place key non-sn items at front of variable list
order state ea parent_key enum_identity start_time end_time submissiondate today_auto today_manu, first
 
* Checking skip patterns:
*For all modules:
*hhh_pull_factor is removed from the list as hhh_pull_factor_spec has a wrong constraint built into the questionnaire.
foreach var of varlist hhh_push_factor hhh_tribe tenure waste hunger_coping harm_location harm_outcome dispute_resolve move_why {
	assert missing(`var'_spec) if `var' != 1000
}
assert missing(hhh_migra_time) if hhh_migration_kdk != 1
recode hhh_migra_time (.=.z) if hhh_migration_kdk != 1
assert water_time_sum == 0 | missing(water_time_sum) if water_time_kdk != 1
recode water_time_sum (.=.z) if water_time_kdk != 1
foreach x in tmarket tedu thealth {
	assert `x'_sum == 0 if `x'_dk !=1
	recode `x'_sum (.=.z) if `x'_dk !=1
	drop `x'_d `x'_h `x'_m `x'_dk
}
*Drop unnecessary variables:
drop hhh_migration_y hhh_migration_m hhh_migration_kdk water_time_d water_time_h water_time_kdk
*Module A:
assert missing(migr_dec13_cause) if migr_dec13 != 1
recode migr_dec13_cause (.=.z) if migr_dec13 != 1
*Module C:
assert missing(hhh_birthplace_other) if hhh_birthplace != 1000
assert missing(hhh_birthplace_ssd) if hhh_birthplace != 1
assert missing(countyborn) if hhh_birthplace != 1 | hhh_birthplace_ssd <= 0
assert missing(hhh_migra_number) if hhh_migra_time >12
assert missing(hhh_migra_from_state) if hhh_migra_from != 3
assert missing(hhh_migra_from_county) if hhh_migra_from != 2 | hhh_migra_from_state <= 0
assert missing(hhh_migra_from_region) if hhh_migra_from != 4
assert missing(hhh_push_factor) if hhh_migra_time >= 60
assert missing(hhh_pull_factor) if hhh_migra_time >= 60
*Recode
recode hhh_birthplace_ssd (.=.z) if hhh_birthplace != 1
recode countyborn (.=.z) if hhh_birthplace != 1 | hhh_birthplace_ssd <= 0
recode hhh_migra_number (.=.z) if hhh_migra_time >12
recode hhh_migra_from_state (.=.z) if hhh_migra_from != 3
recode hhh_migra_from_county (.=.z) if hhh_migra_from != 2 | hhh_migra_from_state <= 0
recode hhh_migra_from_region (.=.z) if hhh_migra_from != 4
recode hhh_push_factor (.=.z) if hhh_migra_time >= 60
recode hhh_pull_factor (.=.z) if hhh_migra_time >= 60
*Module D
assert missing(land_own_dur_n_main) if tenure != 1
assert missing(land_own_gen_main) if land_own_dur_n_main != 5
*The relevance condition for land_legal_main coded in the questionnaire is wrong.
assert missing(drink_source) if water_home != 0
foreach var of varlist land_use land_own_dur_n land_legal {
	assert missing(`var') if land_own != 1
	recode `var' (.=.z) if land_own !=1
}
assert missing(land_own_gen) if land_own_dur_n != 5
foreach var of varlist hunger_nores hunger_sleep hunger_daynight{
	assert missing(`var'_freq) if `var' !=1
	recode `var'_freq (.=.z) if `var' !=1
}
*Recode
recode land_own_dur_n_main (.=.z) if tenure != 1
recode land_own_gen_main (.=.z) if land_own_dur_n_main != 5
*The relevance condition for land_legal_main coded in the questionnaire is wrong.
recode drink_source (.=.z) if water_home! = 0
recode land_own_gen (.=.z) if land_own_dur_n != 5
*Module I:
assert missing(dispute_resolve_police) if inlist(dispute_resolve,5,-98,-99)
assert missing(neighborh_problems) if inlist(neighborh_diff,-98,-99)
assert missing(violence_n) if violence != 1
assert missing(move_to_country) if move_want != 2
assert missing(move_to_state) if move_to_country !=1
assert missing(move_to_county) if move_to_country != 1 | move_to_state <= 0
assert missing(move_why) if move_want!= 1 & move_want != 2
foreach var of varlist move_why_multi* {
	assert missing(`var') if (move_want!=1 & move_want != 2) | move_why <=0
	recode `var' (.=.z) if (move_want!=1 & move_want != 2) | move_why <=0
}
assert missing(move_return) if move_want != 1 & move_want != 2
forvalues i = 1/5 {
	assert missing(move_return_other`i') if (move_want != 1 & move_want != 2) | move_return <= 0
	recode move_return_other`i' (.=.z) if (move_want != 1 & move_want != 2) | move_return <= 0
	}
forvalues i = 1/3 {
	assert missing(move_help`i') if (move_want != 1 & move_want != 2) 
	recode move_help`i' (.=.z) if (move_want != 1 & move_want != 2) 
	}
assert missing(idp_job_c) if (treat != 4 & treat != 1) | idp_presence != 1
assert missing(idp_job) if (idp_job_c !=1 & treat != 2 & treat != 3) | idp_presence != 1
assert missing(idp_safe_c) if (treat != 4 & treat != 1) | idp_presence != 1
assert missing(idp_safe) if (idp_safe_c !=1 & treat != 2 & treat != 3) | idp_presence != 1
assert missing(harm_location) if inlist(harm_12m1,-98,-99,0)
assert missing(harm_outcome)  if inlist(harm_12m1,-98,-99,0)
*Recode
recode dispute_resolve_police (.=.z) if inlist(dispute_resolve,5,-98,-99)
recode neighborh_problems  (.=.z)  if inlist(neighborh_diff,-98,-99)
recode violence_n  (.=.z)  if violence != 1
recode move_to_country  (.=.z)  if move_want != 2
recode move_to_state  (.=.z)  if move_to_country !=1
recode move_to_county  (.=.z)  if move_to_country != 1 | move_to_state <= 0
recode move_why  (.=.z)  if move_want!= 1 & move_want != 2
recode move_return  (.=.z)  if inlist(move_want,1,2)
recode idp_job_c  (.=.z)  if (treat != 4 & treat != 1) | idp_presence != 1
recode idp_job  (.=.z)  if (idp_job_c !=1 & treat != 2 & treat != 3) | idp_presence != 1
recode idp_safe_c  (.=.z)  if (treat != 4 & treat != 1) | idp_presence != 1
recode idp_safe  (.=.z)  if (idp_safe_c !=1 & treat != 2 & treat != 3) | idp_presence != 1
recode harm_location  (.=.z)  if inlist(harm_12m1,-98,-99,0)
recode harm_outcome  (.=.z)   if inlist(harm_12m1,-98,-99,0)
label val hhh_migra_from_state lState

*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a -97 .z) all
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "N/A", modify
}
*add value labels to non-valuelabelled variables
ds, not(type string)
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond"  .z "N/A", modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	} 
}
*Drop variables that contain private information
drop hhsid_org respondent_name
*Drop redundant variables: 
drop submissiondate
order state ea enum_identity
*Assign appropriate labels to variables 
label var ea "Enumeration Area"
label var enum_identity "Enumerator ID"
label var duration "Duration of interview (hrs)"
*Generate variable that specifies to which module households were assigned
gen mod_hh = treat 
tab treat
label var mod_hh "Household module assignment"
label var treat "Household module assignment"
*Drop unnecessary variables 
drop res_active res_age res_work sws tag* treat* qr_resp_id accx accx_end hhh_age hhh_name1 hhlid_1lab hhm_mwage_curr_label hhr_age hhr_age_perc hhr_name insample interview_toolong isvalidated length line space
*Rectify order of variables according to questionnaire
order state Urbanicity ea enum_identity mod_hh duration month  
*Value Labels:
label define Urbanicity 0 "Rural" 1 "Urban"
label values Urbanicity Urbanicity
save "${gsdData}/0-RawOutput/hhq.dta", replace
