* This file:
	* Aggregates nonmissing rows
	* Ensures each household has one household head
	* Identify and drop duplicates
	* Drop unnecessary variables and order the variables alphabetically

*Drop empty rows in hhm data
*Merge non-missing values from all other sets of raw data
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_hhq.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_hhm.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_food.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_nonfood.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_livestock.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_assets.dta", keep(match master) nogenerate
*Aggregate non-missing values for each household
gen rownonmiss = rownonmiss_hhq + rownonmiss_hhm + rownonmiss_food + rownonmiss_nonfood + rownonmiss_livestock + rownonmiss_assets
*Drop empty rows in hhm data
drop if rownonmiss_hhm == 0
drop rownonmiss*
egen data = rownonmiss(*), strok

	
*Extract household member IDs
rename key member_key
gen hhmid = substr(member_key,strpos(member_key,"[")+1,strpos(member_key,"]")-strpos(member_key,"[")-1)
destring hhmid, replace
label var hhmid "Household member unique ID"
sort parent_key hhmid
order parent_key hhmid

*Removing leading and trailing blanks and converting the name variables to upper.
replace rhhm_name = strtrim(rhhm_name)
replace rhhm_name = upper(rhhm_name)

*Ensure each observation has a rhhm_name value - Verification: Observations without a rhhm_name have missing data on all variables.
ds parent_key hhmid rhhm_ishead rhhm_add rhhm_skip rhhm_last pos member_key setofhhm* data, not
foreach var of varlist `r(varlist)' {
	tab `var' if missing(rhhm_name)
	assert r(N) == 0
}
drop if missing(rhhm_name)

*Drop household respondents who have an empty "add" row or an additional (and empty) "skip" row
*First drop if add is equal to 0
drop if rhhm_add == 0
*Identify whether any HHs did not have a last member selected
bysort parent_key: egen sumlast = sum(rhhm_last)
assert sumlast == 1
save "${gsdTemp}/preverifyhhm.dta", replace
*Verifying that the household head names are the same as the household head names in hhq.dta
use "${gsdData}/0-RawOutput/hhq.dta", clear
keep parent_key
merge 1:m parent_key using "${gsdTemp}/preverifyhhm.dta", keep(match) nogen
*There are 82 parent_keys in the hhm.dta that do not match with the parent_keys in the cleaned hhq.dta. These are the parent_keys dropped during the cleaning of hhq.dta.
*Respondents were interviewed at the end. Drop all observations where rhhm_skip == 1
drop if rhhm_skip == 1
bysort parent_key: egen sumhead = sum(rhhm_ishead)
assert sumhead == 1

*Set age to missing for household heads who are recorded as 17 years old or younger
tab rhhm_age if rhhm_age < 18 & rhhm_ishead == 1
replace rhhm_age = . if rhhm_age < 18 & rhhm_ishead == 1 & rhhm_age != . & rhhm_ishead != .

*Drop unnecessary variables
drop rhhm_skip rhhm_add rhhm_last sumlast sumhead*

** Identify potential duplicates
ds hhmid member_key pos, not
duplicates tag `r(varlist)', gen(tag)
*Manual observation shows that the entry is a true duplicate
duplicates drop `r(varlist)'

*Generate number of household members per house
bysort parent_key: gen nhhm = _N

*Tag potential duplicate #1: records with identical parentkey, name, and age
duplicates tag parent_key rhhm_name rhhm_age if !missing(rhhm_name) & !missing(rhhm_age) , gen(tag1)
*Manually check duplicates and drop the observation with less information
egen duplicate_group_1 = group(parent_key) if tag1 == 1
*Manual observation shows that the observations are true duplicates.
bysort duplicate_group_1: egen min_data = min(data)
tab min_data if tag1 ==1
*Both duplicates have the same number of complete observations.
*Drop the second observation of both.
bysort duplicate_group_1: egen pos_lat = max(pos)
drop if pos == pos_lat & tag1 == 1 
*Tag potential duplicate #2: records with identical parentkey and name
duplicates tag parent_key rhhm_name hhm_relation hhm_gender if !missing(rhhm_name) & !missing(hhm_gender), gen(tag2)
tab tag2
*Tag groups within duplicate type #2
egen duplicate_group_2 = group(parent_key rhhm_name hhm_relation hhm_gender) if tag2 == 1
*There are 32 pairs of duplicates on the basis of parent_key and rhhm_name
*There are 86 variables in the dataset. Finding out how many data points match across the pairs of potential duplicates.
gen match = 0
sort duplicate_group_2
ds
bysort duplicate_group_2: gen n = _n
ds hhmid pos* member_key setofhhm tag* duplicate* n* min_data nhhm parent_key, not
foreach var in `r(varlist)' { 
	replace match = match + 1 if `var'[_n] == `var'[_n+1] & n == 1 & !missing(`var'[_n])
}
*Manual checking shows that the tagged potential duplicates do not seem to be true duplicates.
drop tag2 duplicate_group_2 match n
*Tag potential duplicate #3: households with identical rosters, identified by first finding household heads with identical names
bysort rhhm_name: egen hhhn = sum(rhhm_ishead)
list rhhm_name if hhhn>1
egen group_name = group(rhhm_name) if hhhn > 1
*There are 2 rhhm_names that appear as household heads more than once in the table. 
gen hh_group = group_name if !missing(group_name) & rhhm_ishead == 1
bysort parent_key: egen hh_group1 = max(hh_group) 
*Now compare household rosters for households with identical household head names and household sizes
bysort hh_group: gen n = _n if !missing(hh_group)
*Comparing household sizes.
gen match = 1 if nhhm[_n] == nhhm[_n+1] & n == 1 
tab match
assert r(N) == 0
*The houehold sizes differ.
sort hh_group1 parent_key rhhm_name
list hh_group1 parent_key rhhm_name rhhm_age rhhm_ishead if hh_group1 > 0 & !missing(hh_group1)
*Manual check shows that the names of other household members are different.
drop match* tag* group_name hh_group* hhhn n min_data duplicate* nhhm data

*Regenerate nhhm variable after the cleaning of data.
bysort parent_key: gen nhhm = _N

*Drop unnecessary variables
drop  *_calc* generated* setofhhm  

*Fix order

*Store names of variables with an item number
local nonsn "parent_key member_key hhmid"
ds `nonsn', not
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space' - 1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","",4)
	*Rename variables their respective item numbers
	rename `var' `sn'`var'
	}

*Reorder based on alphabetic-numeric order
order *, sequential

*Store names of variables with an item number
ds `nonsn', not
*Restore original variable names
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space' - 1)
	*Remove period from item numbers	
	local sn = subinstr(`"`sn'"',".","",4)
	*Create new variable names that do not include the item numbers incorporated earlier
	local newvar = subinstr("`var'","`sn'","",1)
	*Rename variables their earlier variable names
	rename `var' `newvar'
}

*Place key variables without an item number at front of variable list
order `nonsn', first

ren hhm_* *
ren rhhm_* *
*Checking skip patterns:
*Remaining recodes
*first fix some missing variables
replace empl_primary12m = -99 if empl_primary12m == 9
replace empl_primary7d = -99 if empl_primary7d == 9
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "N/A", modify
}
*add value labels to non-valuelabelled variables
ds age empl_act12* empl_dk12* hhmid, not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z"N/A" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
* Relabel skip patterns based on relevance conditions in Questionnaire
* Skip pattern consistency and missing values due to skip patterns . ==> .z
*Relation to household head if ishead == 0 
assert relation==. if ishead==1 
recode relation (.=.z) if ishead==1
assert missing(migr_never) if ishead == 1
recode migr_never (.=.z) if ishead == 1
foreach var of varlist migr_time* migr_oscillation migr_from {
	assert missing(`var') if migr_never != 0
	recode `var' (.=.z) if migr_never != 0
}
replace migr_time_y=.a if migr_time_dk==.a
replace migr_time_m=.a if migr_time_dk==.a
drop migr_time_dk
recode edu_level (.=.z) if edu_current == 1 | edu_ever == 1
recode edu_ever (.=.z) if edu_current == 0
*Occupation related variables occ*
ds occ*, not(type string)
foreach v of varlist `r(varlist)' {
	recode `v' (.=.z) if age<10 
}
recode occ_clerq (.=.z) if occ_lev1 != 4 
recode occ_craft (.=.z) if occ_lev1 != 7
recode occ_elem (.=.z) if occ_lev1 != 9
recode occ_forces (.=.z) if occ_lev1 != 10
recode occ_mgr (.=.z) if occ_lev1 != 1
recode occ_plant (.=.z) if occ_lev1 != 8
recode occ_prof (.=.z) if occ_lev1 != 2
recode occ_service (.=.z) if occ_lev1 != 5
recode occ_skilled (.=.z) if occ_lev1 != 6
recode occ_tech(.=.z) if occ_lev1 != 3
*Employment related variables
foreach v of varlist empl_appr12m empl_farm12m empl_inc12m empl_bus12m empl_fhelp12m {
	recode `v' (.=.z) if age<10 
}	
recode empl_primary12m `v' (.=.z) if empl_act12m < 1 
*Apprenticeship related variables
foreach v of varlist empl_appr12m empl_appr_ever empl_farm_ever empl_inc_ever empl_bus_ever empl_fhelp_ever {
	recode `v' (.=.z) if empl_act12m==0
}	
*Activity in past 7 days 
replace emp_7d_hours=.a if emp_7d_hours_kdk==.a
drop emp_7d_hours_kdk
recode empl_active7d  (.=.z) if empl_act_ever ==0 & empl_dk_ever == 0 
recode empl7d_temp (.=.z) if empl_active7d != 0 & empl_dk_ever !=0 *empl_act_ever != 0 
recode empl_primary7d (.=.z) if empl_active7d == 0
recode empl_primary7d_kind (.=.z) if empl_active7d == 0
recode empl7d_inactive (.=.z) if empl_active7d == 1
recode empl7d_temp (.=.z) if empl_active7d == 1
recode empl_status (.=.z) if empl_active7d == 0 
*Job search 
recode job_search (.=.z) if age <10 | missing(age)
recode job_search_type (.=.z) if age <10 | missing(age)
recode job_search_no (.=.z) if job_search == 1
*Drop unnecessary variables
drop pos emp_12m_a emp_12m_b emp_12m_f emp_12m_h emp_12m_reminder empl_act_ever empl_dk_ever emp_12m_p
*Rename variables by adding relevant prefixes 
save "${gsdData}/0-RawOutput/hhm.dta", replace


