*This do file cleans and standardizes the food consumption data.
	*	Add labels for the food consumption data using label files automatically created by the Survey CTO application
	*	Drop the household-level duplicates identified in the hhq and hhm data
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}		
use "${gsdDataRaw}/food.dta", clear
*Label food.dta file
do "${gsdDo}/0-4-food-1-label.do"
gen n2 = ustrrpos(parent_key,"/")
replace parent_key = substr(parent_key,1,n2-1)
drop n2
*Cleaning of food.dta
*Removing observations from food.dta that correspond to interviews that were dropped in the cleaning of hhq.dta and hhm.dta
merge m:1 parent_key using "${gsdData}/0-RawOutput/hhq.dta", keep(match) keepusing(parent_key) nogen
*There are a total of 1342 parent_keys in food.dta. One parent_key in hhq.dta did not match with food.dta. That interview seemed to have missing a significant number of modules.

*Clean up variable names
rename rf_* *

order parent_key itemid
sort parent_key itemid

*Checks:
assert item_recall == 7
assert cons_low == 1 if cons_quant < c_min_s & cons_quant != 0
assert cons_high == 1 if cons_quant > c_max_s & !missing(cons_quant) 
assert purc_low == 1 if purc_quant < p_min_s & purc_quant != 0
assert purc_high == 1 if purc_quant > p_max_s & !missing(purc_quant)
assert pric_ssp == "error" if missing(pric_curr)
replace pric_ssp = "" if pric_ssp == "error"
destring pric_ssp, replace
assert cons_unit_options == 1 if !missing( cons_quant) & !missing( cons_unit)
assert cons_unit_options != 1 if missing(cons_quant) | missing(cons_unit)

*make one manual correction for one household where a bug in the tablet meant it had one item asked twice and one item dropped
* the item is in a module that is different from the household's assigned module so this has no impact on anything
duplicates report parent_key itemid
duplicates drop parent_key itemid, force
expand 2 if parent_key=="uuid:b565d0fb-c0f4-4f3c-9eee-68b9e51fc938" & itemid==10120, gen(new)
replace itemid=10102 if new==1
*replace all apripriate variables
sort new
foreach v of varlist pric_min pric_max item_name item_category item_module {
	bys itemid: replace `v'=`v'[_n-1] if new==1
}
drop new

*Dropping unnecessary variables:
drop *note* v_avg item_recall setofrep_g
order parent_key itemid item_name
sort parent_key itemid

*Check skip patterns
*encode item_name variable
rename item_name item_name_
encode item_name_, gen(item_name)
drop item_name_
*Check skip patterns
assert consumed == 1 if relevanceyn == 1
drop consumed
ds parent_key key itempos pos itemid item_category item_name item_module relevanceyn *min *max, not
foreach var of varlist `r(varlist)' {
	assert missing(`var') if relevanceyn == 0 
}
assert !missing(cons_quant) if cons_unit_options == 1
assert missing(cons_quant) if cons_unit_options == -98 | cons_unit_options == -99
replace cons_quant = -98 if cons_unit_options == -98
replace cons_quant = -99 if cons_unit_options == -98
replace cons_unit = 0 if cons_unit_options == -98  | cons_unit_options == -99
label define lfoodunit 0 "Not Applicable (Quantity not known)", add
drop cons_unit_options
assert !missing(purc_quant) if purc_unit_options == 1
assert missing(purc_quant) if purc_unit_options == -98 | purc_unit_options == -99
replace purc_quant = -98 if purc_unit_options == -98
replace purc_quant = -99 if purc_unit_options == -99
replace purc_unit = 0 if purc_unit_options == -98 | purc_unit_options == 99 
drop purc_unit_options
assert !missing(pric_total) if pric_total_curr_kdk == 1
assert missing(pric_total) if pric_total_curr_kdk == -98 | pric_total_curr_kdk == -99
replace pric_total = -98 if pric_total_curr_kdk == -98
replace pric_total = -99 if pric_total_curr_kdk == -99
replace pric_total_curr = 0 if pric_total_curr_kdk == -98 | pric_total_curr_kdk == -99 
label define pric_total_curr 0 "Not Applicable (Price not known)", add
drop pric_total_curr_kdk
foreach var of varlist *low *high {
	assert `var' == 1 if !missing(`var')
}
drop *low *high
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*Skip pattern consistency and missing values due to skip patterns . ==> .z
ds, not(type string)
foreach var of varlist `r(varlist)' {
	recode `var' (.=.z)
}
qui label dir
*Categorise missing values: "Don't know": -98 or 98 --> .a "Refused to respond": -99 or 99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
qui label dir
*add value labels to the missing values
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "N/A", modify
}
*add value labels to non-valuelabelled variables
ds itemid parent_key   , not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z "N/A" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
drop itempos pos 
*label variables
label var c_min_s "Soft constraint for quantity consumed"
label var c_max_s "Soft constraint for quantity consumed"
label var p_max_s "Soft constraint for quantity purchased"
label var p_min_s "Soft constraint for quantity purchased"
label var c_min_h "Hard constraint for quantity consumed"
label var c_max_h "Hard constraint for quantity consumed"
label var p_min_h "Hard constraint for quantity purchased"
label var p_max_h "Hard constraint for quantity purchased"
label var cons_conv2kg "Conversion_2_kg factor for unit consumed"
label var purc_conv2kg "Conversion_2_kg factor for unit purchased"
label var pric_max "Soft constraint for price"
label var pric_min "Soft constraint for price"
label var item_module "Optional module of the consumed item"
*drop redundant vars
drop cons_convert purc_convert pric_curr_label pric_zero pric_ssp pric_sspperkg 
*drop if missing(cons) | cons==0
order parent_key item_category item_name
save "${gsdData}/0-RawOutput/food.dta" , replace
