*This do file cleans and standardizes the non-food consumption data.
	*	Add labels for the non-food consumption data using label file automatically created by the Survey CTO application
	*	Drop the household-level duplicates identified in the hhq and hhm data
	*	Checks skip patterns
	* 	Reocdes 'Not Applicables, Don't know and Refused to respond as .z, .a and .b'
*Output files: 
	* 1-CleanInput/nonfood.dta

*Wave 3 food data
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}		
use "${gsdDataRaw}/nonfood.dta", clear
do "${gsdDo}/0-5-nonfood-1-label.do"
ren rnf_* * 

*Removing observations from food.dta that correspond to interviews that were dropped in the cleaning of hhq.dta and hhm.dta (Check how many are not matching and make a note of it.)
merge m:1 parent_key using "${gsdData}/0-RawOutput/hhq.dta", keep(match) keepusing(parent_key) nogen

*Checking the distribution of optional modules:
tab item_module, mis
*Other checks
replace pric_ssp = "" if pric_ssp == "error"
assert pric_ssp == "" if missing(pric_total) | missing(pric_total_curr)
destring pric_ssp, replace

*Encoding item_name and item_category
encode item_name, gen(itemlabel)
label var itemlabel "Item label"
drop item_name 

*Checking skip patterns
assert !missing(pric_total) if pric_total_curr_kdk == 1
assert missing(pric_total) if pric_total_curr_kdk <0
replace pric_total_curr = 0 if pric_total_curr_kdk < 0
label define fpric_curr 0 "Not applicable (Price unknown)", add
drop pric_total_curr_kdk
assert missing(free_yn) if relevanceyn == 0
assert missing(free_main) if free_yn != 1
*Cleaning variables
assert pric_sspperkg_low == 1 if !missing(pric_sspperkg_low)
assert pric_sspperkg_high == 1 if !missing(pric_sspperkg_high)
drop pric_sspperkg*

*Recode Not applicables 
ds, not(type string)
foreach var of varlist `r(varlist)' {
	recode `var' (.=.z)
}
*Categorise missing values: "Don't know": -98 or 98 --> .a "Refused to respond": -99 or 99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "N/A", modify
}

*define variables that do not require labelling of missing values
ds itemid item_module item_recall , not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z "N/A" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}

*Calculate mean number of items consumed for core and non-core items
*Checking the distribution of optional modules and *Calculate mean number of items consumed for core and non-core items
tab item_module, mis
bysort parent_key : egen sum_total = sum(relevanceyn) 
egen mean_total = mean(sum_total)
bysort parent_key: egen sum_core = sum(relevanceyn)  if item_module == 0 
egen mean_core = mean(sum_core)
bysort parent_key: egen sum_opt = sum(relevanceyn)  if item_module == 1 | item_module ==  2 | item_module ==  3 | item_module == 4 
egen mean_opt = mean(sum_opt) 

*Check and recode skip patterns
recode pric_total (.=.z) if relevanceyn==0 | relevanceyn==.a | relevanceyn==.b
recode pric_total_curr (.=.z) if relevanceyn==0 | relevanceyn==.a | relevanceyn==.b

*drop price constraints because they were removed after inflation grew out of hand
drop v_min_s v_min_h v_max_s v_max_h

*Reorder and save as clean input file
*rename 
rename (relevanceyn pric_total pric_total_curr item_module)(cons price curr mod_item )
order item_category itemlabel itemid cons price curr item_recall 
drop sum_total mean_total sum_core mean_core sum_opt mean_opt cons_index v_avg pric_curr_label setofrep_h
save "${gsdData}/0-RawOutput/nonfood.dta", replace
*create a file containing food item labels for future reference
use "${gsdData}/0-RawOutput/nonfood.dta" , clear
collapse itemid , by(itemlabel item_category mod_item)
save "${gsdData}/1-CleanTemp/nonfood_items.dta" , replace
