*This file cleans and standardizes the assets.dta and prepares a sharable version of assets.dta
	*	Add labels from a label file automatically created by the Survey CTO application
	*	Drop the household-level duplicates identified in the hhq and hhm data
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}		
use "${gsdDataRaw}/assets.dta", clear
do "${gsdDo}/0-6-assets-1-label.do"
*Renaming variables
rename ra_* *
labmask index, values(nametitle)

*Cleaning assets.dta
*Removing observations from food.dta that correspond to interviews that were dropped in the cleaning of hhq.dta and hhm.dta.(Check if there is a discrepancy in matching between hhq and assets)
merge m:1 parent_key using "${gsdData}/0-RawOutput/hhq.dta", keep(match) keepusing(parent_key) nogen

*Drop unnecessary variables:
drop nametitle namels namelp key setofrep_j generated_note_name_690 generated_note_name_681 max_s

*Ordering
order prnew_sp, after (prnew)
order sellnew_curr_kdk , after (sellnew)
order sellall_curr_kdk, after (sellall)
order parent_key
sort parent_key index
order parent_key index

*Checking skip patterns
ds parent_key index own xmas xmas_kdk max_h, not
foreach var of varlist `r(varlist)' {
	assert missing(`var') if own != 1
}
*Remove know/dont know variables.
*There are currencies mentioned, even when no price is given.
*Replacing those entries to 0 - 'Not Applicable - Price unknown'.
*Asserting that the prices quoted as 0 are confirmed to be true.
replace owntotal = 0 if own == 0
replace owntotal = -98 if owntotal_kdk == -98
replace owntotal = -99 if owntotal_kdk == -99
drop owntotal_kdk owntotal_high
assert !missing(ynew) if ynew_kdk == 1
replace ynew = -98 if ynew_kdk == -98
replace ynew = -99 if ynew_kdk == -99
drop ynew_kdk
foreach var of varlist prnew sellnew sellall {
	assert missing(`var') if `var'_curr_kdk < 0
	assert !missing(`var') if `var'_curr_kdk == 1
	replace `var' = -98 if `var'_curr_kdk == -98
	replace `var' = -99 if `var'_curr_kdk == -99
	replace `var'_curr = 0 if missing(`var') | `var' == -98 | `var' == -99
	assert `var'zero == 1 if !missing(`var'zero)
	drop `var'_curr_kdk `var'zero
}
assert !missing(xmas) if xmas_kdk == 1
assert missing(xmas) if xmas_kdk != 1 
replace xmas = -98 if xmas_kdk == - 98
replace xmas = -99 if xmas_kdk  == - 99
drop xmas_kdk
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
ds, not (type string)
foreach v of varlist `r(varlist)' {
	recode `v' (.=.z)
}
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "N/A", modify
}
*add value labels to non-valuelabelled variables
ds *_curr, not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z "N/A" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
*Rename variables
rename ( ynew xmas ) ( year_purc owntotal_preconflict )
*Generate pre-conflict ownership indicator
gen own_preconflict = .
replace own_preconflict = 0 if owntotal_preconflict == 0 & !missing(owntotal_preconflict)
replace own_preconflict = 1 if owntotal_preconflict > 0 & !missing(owntotal_preconflict)
label values own_preconflict ra_own
label var own_preconflict "Did the household own any of \${ra_namelp} before the conflict?"
*clean up and save
order parent_key index 
order own_preconflict ,before(owntotal_preconflict)
order max_h, last 
save "${gsdData}/0-RawOutput/assets.dta", replace
