*This do file cleans the livestock usage data. We perform the following steps:
	*	Add labels from a label file automatically created by the Survey CTO application
	*	Drop the household-level duplicates identified in the hhq and hhm data

clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}		
use "${gsdDataRaw}/livestock.dta", clear
do "${gsdDo}/0-7-livestock-1-label.do"
*Renaming variables:
rename rl_* *
labmask index, values(nametitle)

*Cleaning livestock.dta
*Removing observations from livestock.dta that correspond to interviews that were dropped in the cleaning of hhq.dta and hhm.dta. (Check how many observations fail to match with hhq.ta)
merge m:1 parent_key using "${gsdData}/0-RawOutput/hhq.dta", keep(match) keepusing(parent_key) nogen 

*Dropping unnecessary variables:
drop nametitle namels namelp key setofrep_i generated_note_name_593 generated_note_name_602 

*Dropping variables with all missing values:
foreach var of varlist price_today_sp sell_val_sp kill_val_sp give_val_sp buy_val_sp {
	assert missing(`var')
	drop `var'
}
assert own_high == 1 if !missing(own_high)
drop own_high
*Ordering variables:
order price_today_curr_kdk, after (price_today_curr)
sort parent_key index
order parent_key index

*Check skip patterns
ds parent_key index raise max_s max_h, not
foreach var of varlist `r(varlist)' {
assert missing(`var') if raise != 1
}
foreach v of varlist own_n born_n price_today sell_n sell_val kill_n kill_val give_n give_val give_reason buy_n buy_val lose_n lose_val lose_reason {
	recode `v' (.=.z) if raise==0 | raise== -98 | raise== -99
}
foreach var of varlist own_n born_n sell_n kill_n give_n buy_n lose_n {
	assert !missing(`var') if `var'_kdk == 1
	assert missing(`var') if `var'_kdk  == -98 | `var'_kdk == -99
	replace `var' = -98 if `var'_kdk == -98
	replace `var' = -99 if `var'_kdk == -99
	drop `var'_kdk
}
foreach var of varlist price_today sell_val kill_val give_val buy_val lose_val {
	assert !missing(`var') if `var'_curr_kdk == 1
	assert missing(`var') if `var'_curr_kdk == -98 | `var'_curr_kdk == -99
	replace `var' = -98 if `var'_curr_kdk == -98
	replace `var' = -99 if `var'_curr_kdk == 99
	replace `var'_curr = 0 if `var'_curr_kdk == -98 | `var'_curr_kdk == -99
	drop `var'_curr_kdk
}
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
ds raise parent_key lose_val_sp lose_reason_o, not
foreach v of varlist `r(varlist)' {
	recode `v' (.=.z)
}
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "N/A", modify
}
*add value labels to non-valuelabelled variables
ds raise *_curr lose_reason, not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z "N/A" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
order max_h max_s, last
save "${gsdData}/0-RawOutput/livestock.dta", replace
