*This do file
	*	Checks for the balance of treatment
	*	Checks the timing of interviews
	*	Check the duration of interviews
	*	Check the distances between successive interviews conducted by the same enumerator
	*	Producing cumulative counts by team and enumerator
	*	Checking percentage of food shares by team and enumerator
clear all
set more off
set maxvar 10000
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}


*Checking the balance of treatment
use "${gsdData}/0-RawOutput/hhq.dta", clear
*create treat flags
forvalues i = 1/4 {
	gen int mod_`i'= mod_hh==`i'
}
tab mod_hh
local goodvars "today_auto state ea enum_identity hh_id mod_hh mod_*"
keep `goodvars'
order `goodvars'
la var state "State"
la var ea "EA"
la var today_auto "Date"
sort ea hh_id
export excel today_auto state ea enum_identity hh_id mod_* using "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet(interviews) sheetmod first(varl)
*create a summary sheet
gen num_int=1
order num_int, before(hh_id)
collapse (first) today_auto state (sum) num_int mod_1 mod_2 mod_3 mod_4, by(ea)
order state
la var state "State"
la var ea "EA"
la var today_auto "Date of first interview"
la var num_int "Num of Interviews"
*label treat flags
forvalues i = 1/4 {
	la var mod_`i' "Module `i'"
}
merge 1:1 ea using "${gsdDataRaw}/sample_compiled.dta", assert(match using) keep(match)  keepusing(State County Payam Boma Urbanicity phase1 phase2 replacement) 	  
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet(summary) sheetmod first(varl)


*create files with percent items consumed
*Use raw data from the food consumption module and calculate how many items were consumed from each module.
use "${gsdDataRaw}/food.dta", clear
ren parent_key xparent_key
gen parent_key=substr(xparent_key,1,41)
*Eliminate don't know and refused to respond answers.
replace rf_relevanceyn=. if rf_relevanceyn!=1
*Calculate number of items consumed for each module and collapse these counts by interview using parent_key.
forvalues i = 0/4 {
	gen mod`i'_cons=.
	replace mod`i'_cons=1 if rf_item_module==`i' & rf_relevanceyn==1
}
forvalues i = 0/4 {
	gen rf_cons_quant_nonmiss`i'=.
	replace rf_cons_quant_nonmiss`i'=1 if rf_item_module==`i' & rf_relevanceyn==1 & rf_cons_quant!=.
}
collapse (sum) rf_relevanceyn rf_cons_quant_nonmiss? mod*, by(parent_key)
*Calculate percentages of food items consumed for each module.
*Calculate percentage of items consumed out of total items on each list.
gen pct_cons_allfood=rf_relevanceyn/140
gen pct_cons_mod0=mod0_cons/33
gen pct_cons_mod1=mod1_cons/27
gen pct_cons_mod2=mod2_cons/26
gen pct_cons_mod3=mod3_cons/26
gen pct_cons_mod4=mod4_cons/28
egen pct_cons_optional=rowmax(pct_cons_mod1 pct_cons_mod2 pct_cons_mod3 pct_cons_mod4)
gen pct_rf_cons_quant_nonmiss=(rf_cons_quant_nonmiss0+rf_cons_quant_nonmiss1+rf_cons_quant_nonmiss2+rf_cons_quant_nonmiss3+rf_cons_quant_nonmiss4)/rf_relevanceyn
forvalues i = 0/4 {
	gen pct_nonmiss_mod`i'=rf_cons_quant_nonmiss`i'/mod`i'_cons
}
*pct_nonmiss_optional refers to whatever optional module (treat) was used for that interview.
egen pct_nonmiss_optional=rowmax(pct_nonmiss_mod1 pct_nonmiss_mod2 pct_nonmiss_mod3 pct_nonmiss_mod4)
*Save the food percentage scores for each interview. To be merged back in later.
save "${gsdTemp}/food_pct_cons", replace
*Use raw data from the nonfood consumption module and calculate how many items were consumed from each module.
use "${gsdDataRaw}/nonfood.dta", clear
ren parent_key xparent_key
gen parent_key=substr(xparent_key,1,41)
*Eliminate don't know and refused to respond answers.
replace rnf_relevanceyn=. if rnf_relevanceyn!=1
*Calculate number of items consumed for each module and collapse these counts by interview using parent_key.
forvalues i = 0/4 {
	gen mod`i'_cons=.
	replace mod`i'_cons=1 if rnf_item_module==`i' & rnf_relevanceyn==1
}
forvalues i = 0/4 {
	gen rnf_cons_quant_nonmiss`i'=.
	replace rnf_cons_quant_nonmiss`i'=1 if rnf_item_module==`i' & rnf_relevanceyn==1 
}
collapse (sum) rnf_relevanceyn rnf_cons_quant_nonmiss? mod*, by(parent_key)
*Calculate percentages of food items consumed for each module.
*Caluculate percentage of items consumed out of total items on each list.
gen pct_cons_allfood=rnf_relevanceyn/113
gen pct_cons_mod0=mod0_cons/26
gen pct_cons_mod1=mod1_cons/22
gen pct_cons_mod2=mod2_cons/21
gen pct_cons_mod3=mod3_cons/19
gen pct_cons_mod4=mod4_cons/25
egen pct_cons_optional=rowmax(pct_cons_mod1 pct_cons_mod2 pct_cons_mod3 pct_cons_mod4)
gen pct_rnf_cons_quant_nonmiss=(rnf_cons_quant_nonmiss0+rnf_cons_quant_nonmiss1+rnf_cons_quant_nonmiss2+rnf_cons_quant_nonmiss3+rnf_cons_quant_nonmiss4)/rnf_relevanceyn
forvalues i = 0/4 {
	gen pct_nonmiss_mod`i'=rnf_cons_quant_nonmiss`i'/mod`i'_cons
}
*pct_nonmiss_optional refers to whatever optional module (treat) was used for that interview.
egen pct_nonmiss_optional=rowmax(pct_nonmiss_mod1 pct_nonmiss_mod2 pct_nonmiss_mod3 pct_nonmiss_mod4)
*Save the food percentage scores for each interview. To be merged back in later.
save "${gsdTemp}/nonfood_pct_cons", replace

*create a file with EA gps midpoints
use "${gsdData}/0-RawOutput/hhq.dta", clear
keep ea  loc*
collapse loc*, by(ea)
rename * *_ea
rename ea_ea ea
save "${gsdTemp}/gps_check_ea.dta", replace

*create data file for consistency checks
*Calculate interview time.
use "${gsdData}/0-RawOutput/hhq.dta", clear
gen str3 today_auto_month=""
replace today_auto_month="Jan" if month(today_auto)==1
replace today_auto_month="Feb" if month(today_auto)==2
replace today_auto_month="Mar" if month(today_auto)==3
replace today_auto_month="Apr" if month(today_auto)==4
replace today_auto_month="May" if month(today_auto)==5
replace today_auto_month="Jun" if month(today_auto)==6
replace today_auto_month="Jul" if month(today_auto)==7
replace today_auto_month="Aug" if month(today_auto)==8
replace today_auto_month="Sep" if month(today_auto)==9
replace today_auto_month="Oct" if month(today_auto)==10
replace today_auto_month="Nov" if month(today_auto)==11
replace today_auto_month="Dec" if month(today_auto)==12
*check how many interviews have odd duration (negative or greater than 300 minutes)
gen long_duration= duration>300
su long_duration
gen negative_duration= duration<0
su negative_duration
gen duration_clean=duration if duration<300 & duration>0
*Generate indicator variable for same day interviews
gen start_date=dofc(start_time)
gen end_date=dofc(end_time)
gen sameday = .
replace sameday = 0 if start_date != end_date & start_date != . & end_date != .
replace sameday = 1 if start_date == end_date & start_date != . & end_date != .
tab sameday
*generate date difference
gen date_diff=start_date-end_date
tab date_diff
su date_diff, detail

*What were the distances between successive interviews for each enumerator?
*First generate amount of overlapped time between successive interviews
sort enum_identity start_time
by enum_identity: gen overlap = (end_time[_n] - start_time[_n+1]) / 3600000
replace overlap = overlap / 24
replace overlap = 0 if overlap <= 0
*Next generate distances between successive interviews among each enumerator
do "${gsdDo}/fDistance.do"
sort enum_identity start_time, stable
by enum_identity: gen loclatitude_a = loclatitude[_n+1]
by enum_identity: gen loclongitude_a = loclongitude[_n+1]
quietly fDistance loclatitude loclongitude loclatitude_a loclongitude_a dist_a
replace dist_a = dist_a / 1000
*Generate time difference between successive interviews among each enumerator
sort enum_identity start_time, stable
by enum_identity: gen timediff = (start_time[_n+1] - end_time[_n]) / 3600000
replace timediff = 0 if timediff < 0
*Look at time differences between interviews that were more than 200 kilometers apart
tab timediff dist_a if dist_a > 200 & dist_a != . & overlap == 0
*Time difference is substantial.
*Calculate implied travel speed (km/hr) between interviews
gen speed = dist_a / timediff
*List time differences for very long distances between successive interviews
su speed, detail

*check how distant interviews are per EA
*merge with ea gps data and check distance
merge m:1 ea using "${gsdTemp}/gps_check_ea.dta", nogen
*check distance
vincenty loclatitude loclongitude loclatitude_ea loclongitude_ea, inkm v(dist)
sort ea dist 
su dist, detail
gen suspicious=(dist>1) if !missing(dist)

*Generate table with merged food score and nonfood score data; save for later use
merge 1:1 parent_key using "${gsdTemp}/food_pct_cons", keep(match) nogen
merge 1:1 parent_key using "${gsdTemp}/nonfood_pct_cons", keep(match) nogen
save "${gsdTemp}\hhq_consistencychecks.dta", replace
*clean up and export to excel file
local goodvars "state ea replace_yn replacement enum_identity today_auto today_manu date_diff start_time end_time mod_hh parent_key today_auto_month today_auto_month long_duration negative_duration duration_clean start_date end_date sameday date_diff overlap loclatitude_a loclongitude_a dist_a timediff speed locaccuracy_ea localtitude_ea loclatitude_ea loclongitude_ea dist suspicious rf_relevanceyn rf_cons_quant_nonmiss0 rf_cons_quant_nonmiss1 rf_cons_quant_nonmiss2 rf_cons_quant_nonmiss3 rf_cons_quant_nonmiss4 mod0_cons mod1_cons mod2_cons mod3_cons mod4_cons pct_cons_allfood pct_cons_mod0 pct_cons_mod1 pct_cons_mod2 pct_cons_mod3 pct_cons_mod4 pct_cons_optional pct_rf_cons_quant_nonmiss pct_nonmiss_mod0 pct_nonmiss_mod1 pct_nonmiss_mod2 pct_nonmiss_mod3 pct_nonmiss_mod4 pct_nonmiss_optional rnf_relevanceyn rnf_cons_quant_nonmiss0 rnf_cons_quant_nonmiss1 rnf_cons_quant_nonmiss2 rnf_cons_quant_nonmiss3 rnf_cons_quant_nonmiss4 pct_rnf_cons_quant_nonmiss"
keep `goodvars'
order `goodvars'
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet("Overview") sheetmod first(varl)

*Indicators by enumerator
use  "${gsdTemp}\hhq_consistencychecks.dta", clear
gen interview_count=1
tab mod_hh, gen(mod_hh)
*Collapse all relevant indicators by enumerator and sort by enumerator
collapse (sum) interview_count=interview_count replacement mod_hh? (min) state first_date=today_manu (p50) med_pct_food_QC_all=pct_rf_cons_quant_nonmiss med_intv_time=duration med_pct_food_all=pct_cons_allfood med_pct_food_core=pct_cons_mod0 med_pct_food_opt=pct_cons_optional med_pct_food_QC_core=pct_nonmiss_mod0 med_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_pct_food_QC_all=pct_rf_cons_quant_nonmiss mean_pct_food_all=pct_cons_allfood mean_pct_food_core=pct_cons_mod0 mean_pct_food_opt=pct_cons_optional mean_pct_food_QC_core=pct_nonmiss_mod0 mean_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_intv_time=duration (min) min_intv_time=duration (max) max_intv_time=duration, by(enum_identity)
format *int* %3.0f
sort enum_identity
*Label variables for output and add state labels
la var enum_identity "Enumerator Name"
la var state "Team (state)"
la var interview_count "Number of interviews completed (cumulative)"
la var first_date "Earliest interview date"
la var med_intv_time "Median interview time in minutes"
la var med_pct_food_all "Median % food items consumed"
la var med_pct_food_core "Median % food items consumed from core module"
la var med_pct_food_opt "Median % food items consumed from optional module"
la var med_pct_food_QC_core "Median % quantities for consumed items, core module"
la var med_pct_food_QC_opt "Median % quantities for consumed items, optional module"
la var mean_pct_food_all "Mean % food items consumed"
la var mean_pct_food_core "Mean % food items consumed from core module"
la var mean_pct_food_opt "Mean % food items consumed from optional module"
la var mean_pct_food_QC_core "Mean % quantities for consumed items, core module"
la var mean_pct_food_QC_opt "Mean % quantities for consumed items, optional module"
la var mean_intv_time "Mean interview time in minutes"
la var min_intv_time "Minimum interview time in minutes"
la var max_intv_time "Maximum interview time in minutes"
la var med_pct_food_QC_all "Median % quantities for consumed items, all food items"
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet("By enumerator") sheetmod first(varl)

*Indicators by team
*Use interview table with merged food item scores
use  "${gsdTemp}\hhq_consistencychecks.dta", clear
gen interview_count=1
tab mod_hh, gen(mod_hh)
*Collapse all relevant indicators by enumerator and sort by enumerator
collapse (sum) interview_count=interview_count replacement mod_hh? (sum) replace_yn (min) first_date=today_manu (p50) med_pct_food_QC_all=pct_rf_cons_quant_nonmiss med_intv_time=duration med_pct_food_all=pct_cons_allfood med_pct_food_core=pct_cons_mod0 med_pct_food_opt=pct_cons_optional med_pct_food_QC_core=pct_nonmiss_mod0 med_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_pct_food_QC_all=pct_rf_cons_quant_nonmiss mean_pct_food_all=pct_cons_allfood mean_pct_food_core=pct_cons_mod0 mean_pct_food_opt=pct_cons_optional mean_pct_food_QC_core=pct_nonmiss_mod0 mean_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_intv_time=duration (min) min_intv_time=duration (max) max_intv_time=duration, by(state)
format *int* %3.0f
sort state
gen pct_HH_replacements=replacement/interview_count
*Label variables for output and add state labels
la var state "State (team)"
la var interview_count "Number of interviews completed (cumulative)"
la var replace_yn "Number of replacement EAs visited (valid or invalid)"
la var first_date "Earliest interview date"
la var med_intv_time "Median interview time in minutes"
la var med_pct_food_all "Median % food items consumed"
la var med_pct_food_core "Median % food items consumed from core module"
la var med_pct_food_opt "Median % food items consumed from optional module"
la var med_pct_food_QC_core "Median % quantities for consumed items, core module"
la var med_pct_food_QC_opt "Median % quantities for consumed items, optional module"
la var mean_intv_time "Mean interview time in minutes"
la var min_intv_time "Minimum interview time in minutes"
la var max_intv_time "Maximum interview time in minutes"
la var pct_HH_replacements "% of replacement HH not in selected 12"
la var med_pct_food_QC_all "Median % quantities for consumed items, all food items"
*Export to dashboard excel file; modify only that tab
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet("By state") sheetmod first(varl)

*indicators by EA
use  "${gsdTemp}\hhq_consistencychecks.dta", clear
gen interview_count=1
merge m:1 ea using "${gsdDataRaw}/sample_compiled.dta", assert(match using) keep(match) keepusing(County Payam Boma phase1 phase2 replacement) nogen 	  
collapse (first) firstdate=today_manu (last) lastdate=today_manu (sum) interview_count, by(ea state County Payam Boma Urbanicity phase1 phase2 )
gen incomplete = 0
replace incomplete = 1 if interview_count < 12
label var interview_count "Number of interviews"
label var ea "EA"
label var firstdate "Date of first interview"
label var lastdate "Date of last interview"
format ea %20.0f 
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet("By EA") sheetmod first(varl)

*Cumulative interview count for the whole project
*Use formated data and create balanced time series; generate cumulative counts
use "${gsdData}/0-RawOutput/hhq.dta", clear
gen interview_count=1
gen today_manu_dow=dow(today_manu)
gen wBegin = today_manu-today_manu_dow
collapse (sum) interview_count, by(wBegin)
tsset wBegin, delta(7)
tsfill
gen interview_count_cumul=sum(interview_count)
*Label variables for output
la var wBegin "Week of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of conducted interview - Cumulative"
format wBegin %td
*Export to dashboard excel file; modify only that tab
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet("Cum. - whole project") sheetmod first(varl)
*cumulative indicators by enumerator
*Use formated data and collapse by enumerator
use "${gsdData}/0-RawOutput/hhq.dta", clear
*drop a few observations with a clearly wrong date
drop if today_manu>30000
gen interview_count=1
collapse (sum) interview_count, by(enum_identity today_manu)
sort enum_identity today_manu
*Convert enumerator identity into a number to allow for timeseries operations; generate cumulative counts
encode enum_identity, gen(enum_num)
drop enum_identity
order enum_num
tsset enum_num today_manu
tsfill, full
by enum_num: gen interview_count_cumul=sum(interview_count)
*Label variables for output
la var enum_num "Enumerator"
la var today_manu "Day of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of conducted interview - Cumulative"
*Export to dashboard excel file; modify only that tab
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet("Cum. - enumerators") sheetmod first(varl)
*cumulative indicators by team
*Use formated data and collapse by state; create balanced time series and cumulative counts
use "${gsdData}/0-RawOutput/hhq.dta", clear
*drop a few observations with a clearly wrong date
drop if today_manu>30000
gen interview_count=1
order state today_manu interview_count
collapse (sum) interview_count, by(state today_manu)
sort state today_manu
tsset state today_manu
tsfill, full
by state: gen interview_count_cumul=sum(interview_count)
*Label variables for output
la var state "Team (state)"
la var today_manu "Day of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of interviews completed - Cumulative"
*Export to dashboard excel file; modify only that tab
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet("Cum. - team") sheetmod first(varl)
