*This do file calculates weights.
*Check if filepaths have been established using init.do
clear all
set more off
set maxvar 10000
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
set sortseed 100590
*Preparing the Sample Frame
*** Building replacement sequence. From previous waves experience, we know that the replacements are done in sequence.
***This means that the selected enumeration areas and the replacement enumeration areas are assigned a serial number.
*** In Wave 3, we have the serial numbers assigned to the selected enumeration areas but we do not have serial numbers for replacement enumeration areas.
*** However, replacements were done in batches, and there were three rounds of replacements. 
*** We will recreate the assignment of replacement enumeration areas to original enumeration areas. 
use "${gsdData}/0-RawOutput/hhq.dta", clear
collapse Urbanicity, by(state ea)
tostring Urbanicity, replace
replace Urbanicity = "Urban" if Urbanicity == "1"
replace Urbanicity = "Rural" if Urbanicity == "0"
merge 1:1 ea using "${gsdDataRaw}/Sample_compiled.dta"
*Out of a total of 350 intended EAs, 
gen ea_field = 0 
replace ea_field = 1 if _merge == 3
gen replacement_field_1  = 0 if replacement == 1
replace replacement_field_1 = 1 if replacement == 1 & _merge == 3
gen replacement_field_2 = 0 if replacement == 2
replace replacement_field_2 = 1 if replacement == 2 & _merge == 3
gen replacement_field_3 = 0 if replacement == 3
replace replacement_field_3 = 1 if replacement == 3 & _merge == 3
drop _merge
gen insample_field = 1 if replacement == 0 & ea_field == 1
replace insample_field = 0 if replacement == 0 & ea_field == 0
*Out of a total of 350 EAs in the sample, 100 EAs were surveyed. 
*Out of a total of 197 possible replacement enumeration areas selected with the sample, 45 enumeration areas were used in the first batch of replacement.
*Out of a total of 40 possible replacement enumeration areas selected for the second batch of replacements, 11 were used for replacements in field.
*Out of a total of 10 possible replacement enumeration areas selected for the third batch of replacements, 8 were used for replacements in field.
_strip_labels ea
tostring ea, replace u
drop state
replace State = "Western Equatoria" if State == "Western Equtoria"
label drop lState
label define lState 81 "Warrap" 82 "Northern Bahr-El-Ghazel" 83 "Western Bahr-El-Ghazel" 84 "Lakes" 91 "Western Equatoria" 92 "Central Equatoria" 93 "Eastern Equatoria"
replace State = "81" if State == "Warrap"
replace State = "82" if State == "Northern Bahr-El-Ghazel"
replace State = "83" if State == "Western Bahr-El-Ghazel"
replace State = "84" if State == "Lakes"
replace State = "91" if State == "Western Equatoria"
replace State = "92" if State == "Central Equatoria"
replace State = "93" if State == "Eastern Equatoria"
destring State, replace 
label values State lState
drop stratum
egen stratum = group(State Urbanicity)
label var stratum "Strata"
save "${gsdTemp}/pre_replacements.dta", replace

* For first batch:
*Starting replacement enumeration area serial numbers - for first batch of replacements:
gen rand = runiform(0,1) if replacement_field_1 == 1
bysort State Urbanicity: egen replacement_rank = rank(rand)
keep if insample_field== 0 | replacement_field_1 == 1
gen n = replacement_rank
sort State Urbanicity replacement_field_1 SN
by State Urbanicity replacement_field_1: replace n = _n if replacement_field_1 != 1
sort State Urbanicity n replacement
by State Urbanicity n: gen replacement_ea = ea if replacement == 1
by State Urbanicity n: replace replacement_ea = replacement_ea[_n+1] if _n==1
keep if replacement == 0 & !missing(replacement_ea) 
keep ea replacement_ea
save "${gsdTemp}\replacements_1.dta", replace

*For second batch:
use "${gsdTemp}/pre_replacements.dta", clear
merge 1:1 ea using "${gsdTemp}\replacements_1.dta", keep(master) keepusing(ea) nogen
gen rand = runiform(0,1) if replacement_field_2 == 1
bysort State Urbanicity: egen replacement_rank = rank(rand)
keep if insample_field== 0 | replacement_field_2 == 1
gen n = replacement_rank
sort State Urbanicity replacement_field_2 SN
by State Urbanicity replacement_field_2: replace n = _n if replacement_field_2 != 1
sort State Urbanicity n replacement
by State Urbanicity n: gen replacement_ea = ea if replacement == 2
by State Urbanicity n: replace replacement_ea = replacement_ea[_n+1] if _n == 1
keep if replacement == 0 & !missing(replacement_ea) 
keep ea replacement_ea
append using "${gsdTemp}\replacements_1.dta"
save "${gsdTemp}/replacements_2.dta", replace

*For third batch:
use "${gsdTemp}/pre_replacements.dta", clear
merge 1:1 ea using "${gsdTemp}\replacements_2.dta", keep(master) keepusing(ea) nogen
gen rand = runiform(0,1) if replacement_field_3 == 1
bysort State Urbanicity: egen replacement_rank = rank(rand)
keep if insample_field == 0 | replacement_field_3 == 1
gen n = replacement_rank
sort State Urbanicity replacement_field_3 SN
by State Urbanicity replacement_field_3: replace n = _n if replacement_field_3 != 1
sort State Urbanicity n replacement
by State Urbanicity n: gen replacement_ea = ea if replacement == 3
by State Urbanicity n: replace replacement_ea = replacement_ea[_n+1] if _n == 1
keep if replacement == 0 & !missing(replacement_ea) 
keep ea replacement_ea
append using "${gsdTemp}\replacements_2.dta"
save "${gsdTemp}/replacements_combined.dta", replace

*prepare HHinstratum data
import delimited using "${gsdDataRaw}/General/HHinstratum_W1.csv", varn(1) clear
rename (state urbanicity hhinstratum) (State Urbanicity HHinStratum2)
save "${gsdTemp}/HHinStratum.dta" , replace

*Bring in replacement EAs and establish final EA sample with probabilities of selection of an EA.
use "${gsdTemp}/pre_replacements.dta", clear
merge 1:1 ea using "${gsdTemp}/replacements_combined", keep(master using match)
gen ea_orig = ea
gen ea_field_n = ea
replace ea_field_n = replacement_ea if _merge == 3
label var ea_orig "EA from sample - used for prob of EA's selection"
label var ea_field_n "EA from fieldwork (differs because of replacements)"
drop _merge
keep if replacement == 0
*Correcting inconsistencies in HHinStratum, merge number of HH inStratum from Waves 1 and 2:
merge m:1 State Urbanicity using "${gsdTemp}/HHinStratum.dta", assert(match) nogen
replace HHinStratum=HHinStratum2 
drop HHinStratum2
bysort stratum: egen mean_HHstratum = mean(HHinStratum)
bysort stratum: assert round(HHinStratum) == round(mean_HHstratum)
bysort stratum: gen nea_stratum = _N
replace ProbabilityofselectedEasP1 = Households/HHinStratum
gen P1 = ProbabilityofselectedEasP1 * nea_stratum
save "${gsdTemp}/EA_Master_field_withP1.dta", replace

*Obtaining number of households from Listing data:
import delimited "${gsdDownloads}/Wave 2 Listing Form.csv", bindquote(strict) clear 
gen double ea = ea_v
replace ea = r_ea_12dig if missing(ea_v)
drop ea_v r_ea_12dig
ren key parent_key
save "${gsdTemp}/Wave_3_listing.dta", replace

import delimited "${gsdDownloads}/Wave 2 Listing Form-hhids.csv", bindquote(strict) clear 
drop if hh_add == 0
merge m:1 parent_key using "${gsdTemp}/Wave_3_listing.dta", nogen
bysort ea: gen nhhc = _N
keep ea nhhc
duplicates drop
ren ea ea_field_n
rename nhhc nhh_ea_list
format ea_field_n %18.0g
tostring ea_field_n, replace u
merge 1:1 ea_field_n using "${gsdTemp}/EA_Master_field_withP1.dta", nogen
replace nhh_ea_list = Households if missing(nhh_ea_list) | nhh_ea_list < 30
save "${gsdTemp}/EA_Master_field_withP1andlist.dta", replace
*Calculate number of households surveyed in each EA:
use "${gsdData}/0-RawOutput/hhq.dta", clear
bysort state ea: gen n = _N
collapse n, by(state ea)
_strip_labels ea
tostring ea, replace u
ren (ea n) (ea_field_n nhh_sample)
merge 1:1 ea_field_n using "${gsdTemp}/EA_Master_field_withP1andlist.dta", keep(match) nogen
ren (Households) (nhh_ea_cens)
*Calculate sampling weights based on the census and based on the listing
foreach k in cens list {
	*Then calculate probability of HH selection
	gen p2_`k' = nhh_sample / nhh_ea_`k'
	*Next caculate the weight as the inverse joint probability of HH and EA selection
	gen pweight_`k' = 1/(P1 * p2_`k')
	*Next generate sum of weights by state-stratum
	bysort state Urbanicity: egen tot_pweight_`k' = sum(nhh_sample * pweight_`k')
	bysort state Urbanicity: egen xcheck_`k' = total(nhh_sample * pweight_`k')
}
gen weight = pweight_list * tot_pweight_cens / tot_pweight_list
*Scaling weights to represent the Stratum population:
replace weight = weight * (38/8) if State == 81 & Urbanicity == "Rural"
replace weight = weight * (12/5) if State == 81 & Urbanicity == "Urban"
replace weight = weight * (40/20) if State == 82 & Urbanicity == "Rural"
replace weight = weight * (10/5) if State == 82 & Urbanicity == "Urban"
replace weight = weight * (17/14) if State == 83 & Urbanicity == "Rural"
replace weight = weight * (33/12) if State == 83 & Urbanicity == "Urban"
replace weight = weight * (40/19) if State == 84 & Urbanicity == "Rural"
replace weight = weight * (10/5) if State == 84 & Urbanicity == "Urban"
replace weight = weight * (37/18) if State == 91 & Urbanicity == "Rural"
replace weight = weight * (13/7) if State == 91 & Urbanicity == "Urban"
replace weight = weight * (37/16) if State == 92 & Urbanicity == "Rural"
replace weight = weight * (13/10) if State == 92 & Urbanicity == "Urban"
replace weight = weight * (40/20) if State == 93 & Urbanicity == "Rural"
replace weight = weight * (10/5) if State == 93 & Urbanicity == "Urban"
*Check
bysort state Urbanicity: egen xcheck = total(nhh_sample * weight)
assert (round(HHinStratum) == round(xcheck))
*Keep weights
keep stratum ea_field_n weight pweight_cens
label var weight "Population weight based on listing scaled to Census"
label var pweight_cens "Population weight based on Census"
ren ea_field_n ea
destring ea, replace 
format ea %18.0g
*Save data
save "${gsdTemp}/Weights.dta", replace
*Merge weights into hhq data
*Load hhq data and merge pweights
use "${gsdData}/0-RawOutput/hhq.dta", clear
merge m:1 ea using "${gsdTemp}/Weights.dta", assert(match) keep(match master) keepusing(weight) nogen
*Set Survey data
egen stratum = group(state Urbanicity)
label var stratum "Strata"
svyset ea [pweight=weight] , strata(stratum)
qui tabout state Urbanicity using "${gsdOutput}/Raw-Data 0.xls", svy c(freq) pop replace
save "${gsdData}/0-RawTemp\hhq_withweights.dta", replace
